@@ -7,7 +7,7 @@ use Catmandu::Store::DBI::Bag;
 use Moo;
 use namespace::clean;
 
-our $VERSION = "0.0510";
+our $VERSION = "0.0511";
 
 with 'Catmandu::Store';
 with 'Catmandu::Transactional';
@@ -133,6 +133,12 @@ sub DEMOLISH {
 
 1;
 
+__END__
+
+=pod
+
+=encoding utf8
+
 =head1 NAME
 
 Catmandu::Store::DBI - A Catmandu::Store plugin for DBI based interfaces
@@ -151,7 +157,7 @@ Version 0.0424
     use Catmandu;
 
     my $store = Catmandu->store('DBI',
-        data_source => 'dbi:mysql:database=test', 
+        data_source => 'dbi:mysql:database=test',
         username => 'foo', # optional
         password => 'bar', # optional
     );
@@ -177,13 +183,13 @@ Version 0.0424
 
 A Catmandu::Store::DBI is a Perl package that can store data into
 DBI backed databases. The database as a whole is  a 'store'
-L<Catmandu::Store>. Databases tables are 'bags' (L<Catmandu::Bag>). 
+L<Catmandu::Store>. Databases tables are 'bags' (L<Catmandu::Bag>).
 
-Databases need to be preconfigured for accepting Catmandu data. When 
-no specialized Catmandu tables exist in a database then Catmandu will 
+Databases need to be preconfigured for accepting Catmandu data. When
+no specialized Catmandu tables exist in a database then Catmandu will
 create them automatically. See  "DATABASE CONFIGURATION" below.
 
-DO NOT USE Catmandu::Store::DBI on an existing database! Tables and 
+DO NOT USE Catmandu::Store::DBI on an existing database! Tables and
 data can be deleted and changed.
 
 =head1 CONFIGURATION
@@ -195,7 +201,7 @@ data can be deleted and changed.
 Required. The connection parameters to the database. See L<DBI> for more information.
 
 Examples:
-    
+
       dbi:mysql:foobar   <= a local mysql database 'foobar'
       dbi:Pg:dbname=foobar;host=myserver.org;port=5432 <= a remote PostGres database
       dbi:SQLite:mydb.sqlite <= a local SQLLite file based database mydb.sqlite
@@ -206,7 +212,6 @@ Drivers for each database need to be available on your computer. Install then wi
     cpanm DBD::mysql
     cpanm DBD::Pg
     cpanm DBD::SQLite
-    cpanm DBD::Oracle
 
 =item user
 
@@ -218,13 +223,13 @@ Optional. A password for connecting to the database
 
 =item timeout
 
-Optional. Timeout for a inactive database handle. When timeout is reached, Catmandu 
+Optional. Timeout for a inactive database handle. When timeout is reached, Catmandu
 checks if the connection is still alive (by use of ping) or it recreates the connection.
 See TIMEOUTS below for more information.
 
 =item reconnect_after_timeout
 
-Optional. When a timeout is reached, Catmandu reconnects to the database. By 
+Optional. When a timeout is reached, Catmandu reconnects to the database. By
 default set to '0'
 
 =back
@@ -233,7 +238,7 @@ default set to '0'
 
 When no tables exists for storing data in the database, then Catmandu
 will create them. By default tables are created for each L<Catmandu::Bag>
-which contain an '_id' and 'data' column. 
+which contain an '_id' and 'data' column.
 
 This behavior can be changed with mapping option:
 
@@ -253,6 +258,11 @@ This behavior can be changed with mapping option:
         }
     );
 
+For keys that have a corresponding table column configured, the method 'select' of class L<Catmandu::Store::DBI::Bag> provides
+a more efficiënt way to query records.
+
+See L<Catmandu::Store::DBI::Bag> for more information.
+
 =head2 Column types
 
 =over
@@ -313,6 +323,6 @@ This has the following reasons:
 
 =head1 SEE ALSO
 
-L<Catmandu::Bag>, L<Catmandu::Searchable>, L<DBI>
+L<Catmandu::Bag>, L<DBI>
 
 =cut
